"""

This module defines classes and global functions for interacting with Amazon Web Services.
"""
from _ec2 import get_credentials, launch_EC2, list_instances, set_credentials, status, terminate_EC2
